=====================================
``psyclone.psyir.symbols.datasymbol``
=====================================

.. automodule:: psyclone.psyir.symbols.datasymbol

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.symbols.datasymbol
